Crate timsrust_core

Crate timsrust_core 

This crate allows to read Bruker TimsTOF data.

Basics

Two primary data types are exposed:

  • Spectra: A traditional representation that expresses intensitites in function of mz values for a given precursor.
  • Frames: All recorded data from a single TIMS elution (i.e. at one specific retention_time).

File formats

Two file formats are supported:

  • Bruker .d folder containing:
    • analysis.tdf
    • analysis.tdf_bin
  • miniTDF - ProteoScape optimized Bruker file-format. Similar to TDF, miniTDF consists of multiple files: a binary ‘.bin’ and an index ‘.parquet’ file. The file-names are made up to the following convention: <producing-engine-name>.<domain-name>.<extension>. e.g. for MS2 spectrum information: <producing-engine-name>.ms2spectrum.<extension>. Therefore the following files are expected in the provided ms2 folder:
    • *.ms2spectrum.bin
    • *.ms2spectrum.parquet

Re-exports

pub use timsrust_utils as utils;

Structs

BitConverter
Charge
CoordinateError
Frame
A frame with all unprocessed data as it was acquired.
FrameError
FrameIndex
FrameInfo
FrameIons
FrameReader
FrameReaderError
Im
Intensity
IntensityIndex
IonError
IsolationWindow
Mass
Mh
Mz
Precursor
The MS1 precursor that got selected for fragmentation.
PrecursorError
QuadrupoleSettings
The quadrupole settings used for fragmentation.
Rt
ScanIndex
Spectrum
An MS2 spectrum with centroided mz values and summed intensities.
SpectrumError
TofIndex

Enums

AcquisitionType
The kind of acquisition that was used.
MSLevel
The MS level used.
TimsError

Constants

PROTON_MASS

Traits

Converter
ConvertibleTo
InvertibleConverter

Type Aliases

TimsResult