pub struct FrameIndex(/* private fields */);Trait Implementations
Sourceimpl Clone for FrameIndex
impl Clone for FrameIndex
Sourcefn clone(&self) -> FrameIndex
fn clone(&self) -> FrameIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Converter<FrameIndex, Rt> for BitConverter
impl Converter<FrameIndex, Rt> for BitConverter
Sourceimpl Converter<Rt, FrameIndex> for BitConverter
impl Converter<Rt, FrameIndex> for BitConverter
Sourceimpl ConvertibleTo<FrameIndex> for Rt
impl ConvertibleTo<FrameIndex> for Rt
Sourceimpl ConvertibleTo<Rt> for FrameIndex
impl ConvertibleTo<Rt> for FrameIndex
impl Copy for FrameIndex
Sourceimpl Debug for FrameIndex
impl Debug for FrameIndex
Sourceimpl Display for FrameIndex
impl Display for FrameIndex
impl Eq for FrameIndex
Sourceimpl From<FrameIndex> for u32
impl From<FrameIndex> for u32
Sourcefn from(index: FrameIndex) -> Self
fn from(index: FrameIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<FrameIndex> for u64
impl From<FrameIndex> for u64
Sourcefn from(index: FrameIndex) -> Self
fn from(index: FrameIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<FrameIndex> for usize
impl From<FrameIndex> for usize
Sourcefn from(index: FrameIndex) -> Self
fn from(index: FrameIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<FrameIndex> for i64
impl From<FrameIndex> for i64
Sourcefn from(index: FrameIndex) -> Self
fn from(index: FrameIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<FrameIndex> for f64
impl From<FrameIndex> for f64
Sourcefn from(index: FrameIndex) -> Self
fn from(index: FrameIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<u8> for FrameIndex
impl From<u8> for FrameIndex
Sourceimpl From<u16> for FrameIndex
impl From<u16> for FrameIndex
Sourceimpl Hash for FrameIndex
impl Hash for FrameIndex
Sourceimpl Ord for FrameIndex
impl Ord for FrameIndex
Sourcefn cmp(&self, other: &FrameIndex) -> Ordering
fn cmp(&self, other: &FrameIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FrameIndex
impl PartialEq for FrameIndex
Sourcefn eq(&self, other: &FrameIndex) -> bool
fn eq(&self, other: &FrameIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FrameIndex
impl PartialOrd for FrameIndex
impl StructuralPartialEq for FrameIndex
Sourceimpl TryFrom<FrameIndex> for i32
impl TryFrom<FrameIndex> for i32
Sourcetype Error = CoordinateError
type Error = CoordinateError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<i8> for FrameIndex
impl TryFrom<i8> for FrameIndex
Sourceimpl TryFrom<i16> for FrameIndex
impl TryFrom<i16> for FrameIndex
Sourceimpl TryFrom<i32> for FrameIndex
impl TryFrom<i32> for FrameIndex
Sourceimpl TryFrom<i64> for FrameIndex
impl TryFrom<i64> for FrameIndex
Sourceimpl TryFrom<u32> for FrameIndex
impl TryFrom<u32> for FrameIndex
Sourceimpl TryFrom<u64> for FrameIndex
impl TryFrom<u64> for FrameIndex