pub struct IntensityIndex(/* private fields */);Trait Implementations
Sourceimpl Clone for IntensityIndex
impl Clone for IntensityIndex
Sourcefn clone(&self) -> IntensityIndex
fn clone(&self) -> IntensityIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConvertibleTo<Intensity> for IntensityIndex
impl ConvertibleTo<Intensity> for IntensityIndex
Sourceimpl ConvertibleTo<IntensityIndex> for Intensity
impl ConvertibleTo<IntensityIndex> for Intensity
impl Copy for IntensityIndex
Sourceimpl Debug for IntensityIndex
impl Debug for IntensityIndex
Sourceimpl Display for IntensityIndex
impl Display for IntensityIndex
impl Eq for IntensityIndex
Sourceimpl From<IntensityIndex> for u32
impl From<IntensityIndex> for u32
Sourcefn from(index: IntensityIndex) -> Self
fn from(index: IntensityIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<IntensityIndex> for u64
impl From<IntensityIndex> for u64
Sourcefn from(index: IntensityIndex) -> Self
fn from(index: IntensityIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<IntensityIndex> for usize
impl From<IntensityIndex> for usize
Sourcefn from(index: IntensityIndex) -> Self
fn from(index: IntensityIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<IntensityIndex> for i64
impl From<IntensityIndex> for i64
Sourcefn from(index: IntensityIndex) -> Self
fn from(index: IntensityIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<IntensityIndex> for f64
impl From<IntensityIndex> for f64
Sourcefn from(index: IntensityIndex) -> Self
fn from(index: IntensityIndex) -> Self
Converts to this type from the input type.
Sourceimpl From<u8> for IntensityIndex
impl From<u8> for IntensityIndex
Sourceimpl From<u16> for IntensityIndex
impl From<u16> for IntensityIndex
Sourceimpl Hash for IntensityIndex
impl Hash for IntensityIndex
Sourceimpl Ord for IntensityIndex
impl Ord for IntensityIndex
Sourcefn cmp(&self, other: &IntensityIndex) -> Ordering
fn cmp(&self, other: &IntensityIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for IntensityIndex
impl PartialEq for IntensityIndex
Sourcefn eq(&self, other: &IntensityIndex) -> bool
fn eq(&self, other: &IntensityIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for IntensityIndex
impl PartialOrd for IntensityIndex
impl StructuralPartialEq for IntensityIndex
Sourceimpl TryFrom<IntensityIndex> for i32
impl TryFrom<IntensityIndex> for i32
Sourcetype Error = CoordinateError
type Error = CoordinateError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<i8> for IntensityIndex
impl TryFrom<i8> for IntensityIndex
Sourceimpl TryFrom<i16> for IntensityIndex
impl TryFrom<i16> for IntensityIndex
Sourceimpl TryFrom<i32> for IntensityIndex
impl TryFrom<i32> for IntensityIndex
Sourceimpl TryFrom<i64> for IntensityIndex
impl TryFrom<i64> for IntensityIndex
Sourceimpl TryFrom<u32> for IntensityIndex
impl TryFrom<u32> for IntensityIndex
Sourceimpl TryFrom<u64> for IntensityIndex
impl TryFrom<u64> for IntensityIndex